==> scummvm_2.2.0+dfsg1.orig.tar.xz: scummvm-2.2.0/backends/graphics/opengl/pipelines/shader.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef BACKENDS_GRAPHICS_OPENGL_PIPELINES_SHADER_H
#define BACKENDS_GRAPHICS_OPENGL_PIPELINES_SHADER_H

#include "backends/graphics/opengl/pipelines/pipeline.h"

namespace OpenGL {

#if !USE_FORCED_GLES
class Shader;

class ShaderPipeline : public Pipeline {
public:
	ShaderPipeline(Shader *shader);

	virtual void setColor(GLfloat r, GLfloat g, GLfloat b, GLfloat a);

	virtual void drawTexture(const GLTexture &texture, const GLfloat *coordinates);

	virtual void setProjectionMatrix(const GLfloat *projectionMatrix);

protected:
	virtual void activateInternal();
	virtual void deactivateInternal();

	GLint _vertexAttribLocation;
	GLint _texCoordAttribLocation;
	GLint _colorAttribLocation;

	GLfloat _colorAttributes[4*4];

	Shader *const _activeShader;
};
#endif // !USE_FORCED_GLES

} // End of namespace OpenGL

#endif

==> scummvm_2.6.1+dfsg.orig.tar.xz: scummvm-2.6.1/backends/graphics/opengl/pipelines/shader.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef BACKENDS_GRAPHICS_OPENGL_PIPELINES_SHADER_H
#define BACKENDS_GRAPHICS_OPENGL_PIPELINES_SHADER_H

#include "backends/graphics/opengl/pipelines/pipeline.h"

namespace OpenGL {

#if !USE_FORCED_GLES
class Shader;

class ShaderPipeline : public Pipeline {
public:
	ShaderPipeline(Shader *shader);

	virtual void setColor(GLfloat r, GLfloat g, GLfloat b, GLfloat a);

	virtual void drawTexture(const GLTexture &texture, const GLfloat *coordinates, const GLfloat *texcoords);

	virtual void setProjectionMatrix(const GLfloat *projectionMatrix);

protected:
	virtual void activateInternal();
	virtual void deactivateInternal();

	GLint _vertexAttribLocation;
	GLint _texCoordAttribLocation;
	GLint _colorAttribLocation;

	GLfloat _colorAttributes[4*4];

	Shader *const _activeShader;
};
#endif // !USE_FORCED_GLES

} // End of namespace OpenGL

#endif
